# Generated by Django 3.1.7 on 2021-04-10 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PaymentSystem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('group', models.CharField(choices=[('electronic', 'electronic'), ('bank', 'bank')], max_length=10)),
                ('title', models.CharField(max_length=50)),
                ('name', models.CharField(max_length=30)),
                ('account_id', models.PositiveIntegerField()),
                ('unit_id', models.CharField(max_length=100)),
                ('create_invoice', models.BooleanField()),
            ],
            options={
                'db_table': 'mnt_payment_systems',
            },
        ),
    ]
